@@ -7,6 +7,12 @@ from mako.template import Template
 from mako import exceptions
 import os
 import sys
+from django.template.defaulttags import URLNode, csrf_token
+from django.core.urlresolvers import reverse
+
+default_context = {
+    'url' : reverse,
+}
 
 app_template_dirs = []
 fs_encoding = sys.getfilesystemencoding() or sys.getdefaultencoding()
@@ -21,14 +27,23 @@ for app in settings.INSTALLED_APPS:
         app_template_dirs.append(template_dir.decode(fs_encoding))
 
 template_lookup = TemplateLookup(directories=app_template_dirs, input_encoding='utf8', output_encoding='utf8', imports=['from djangobp.textutil import gettext as _'])
+
+
 def render_to_response(filename, dictionary, context_instance=None):
 
+    dictionary.update(default_context)
+    
     if context_instance:
         for context_dict in context_instance.dicts:
             dictionary.update(context_dict)
+    
+    if settings.MAKO_DEFAULT_CONTEXT:
+        dictionary.update(settings.MAKO_DEFAULT_CONTEXT)
+
     try:
         template = template_lookup.get_template(filename)
         return HttpResponse(template.render(**dictionary))
     except:
         return HttpResponseServerError(exceptions.html_error_template().render())
+    
     
\ No newline at end of file
